pub struct OCABundleModel {
pub version: String,
pub digest: Option<SelfAddressingIdentifier>,
pub capture_base: CaptureBase,
pub overlays: Vec<OverlayModel>,
pub attributes: Option<HashMap<String, Attribute>>,
}Fields
version: StringCESR version of the OCA Bundle with OCAS prefix
digest: Option<SelfAddressingIdentifier>capture_base: CaptureBaseoverlays: Vec<OverlayModel>attributes: Option<HashMap<String, Attribute>>Implementations
Sourceimpl OCABundleModel
impl OCABundleModel
pub fn new( capture_base: CaptureBase, overlays: Vec<OverlayModel>, ) -> OCABundleModel
pub fn fill_attributes(&mut self)
Sourcepub fn remove_attribute(&mut self, attr_name: &String)
pub fn remove_attribute(&mut self, attr_name: &String)
Remove attribute from the OCA Bundle if attribute does not exist, nothing will happen
pub fn get_attribute_by_name(&self, name: &str) -> Option<&Attribute>
Sourcepub fn compute_and_fill_digest(
&mut self,
) -> Result<SelfAddressingIdentifier, OCABundleSerializationError>
pub fn compute_and_fill_digest( &mut self, ) -> Result<SelfAddressingIdentifier, OCABundleSerializationError>
This method will compute digest for OCABundle and all it’s members (capture_base and each overlay) filling as well capture_base digest into overlays. It would use external structures instead of the internal Models i.e. OCABundle vs OCABundleModel Arguments:
self- OCABundleModel to compute digest for
Returns:
Result<said::SelfAddressingIdentifier, OCABundleSerializationError>- Result with computed SAID or an error if serialization or digest computation fails.