OCABundleModel

Struct OCABundleModel 

pub struct OCABundleModel {
    pub version: String,
    pub digest: Option<SelfAddressingIdentifier>,
    pub capture_base: CaptureBase,
    pub overlays: Vec<OverlayModel>,
    pub attributes: Option<HashMap<String, Attribute>>,
}

Fields

version: String

CESR version of the OCA Bundle with OCAS prefix

digest: Option<SelfAddressingIdentifier>capture_base: CaptureBaseoverlays: Vec<OverlayModel>attributes: Option<HashMap<String, Attribute>>

Implementations

Source

impl OCABundleModel

pub fn new( capture_base: CaptureBase, overlays: Vec<OverlayModel>, ) -> OCABundleModel

pub fn to_ast(&self) -> OCAAst

Examples found in repository?
examples/generate_ocafile.rs (line 12)
5fn main() {
6    let bundle_path = "tests/assets/semantics/structural_bundle2.json";
7    let bundle_str = fs::read_to_string(bundle_path).expect("failed to read bundle");
8
9    let registry = oca::overlay_file::OverlayLocalRegistry::from_dir("tests/assets/overlay-file/")
10        .expect("load overlays");
11    let bundle = oca::bundle::load(&mut bundle_str.as_bytes(), &registry).expect("load bundle");
12    let ocafile = oca::file::generate_from_ast(&bundle.to_ast());
13
14    println!("{}", ocafile);
15}
pub fn fill_attributes(&mut self)

pub fn remove_attribute(&mut self, attr_name: &String)

Remove attribute from the OCA Bundle if attribute does not exist, nothing will happen

pub fn get_attribute_by_name(&self, name: &str) -> Option<&Attribute>

pub fn compute_and_fill_digest( &mut self, ) -> Result<SelfAddressingIdentifier, OCABundleSerializationError>

This method will compute digest for OCABundle and all it’s members (capture_base and each overlay) filling as well capture_base digest into overlays. It would use external structures instead of the internal Models i.e. OCABundle vs OCABundleModel Arguments:

  • self - OCABundleModel to compute digest for

Returns:

  • Result<said::SelfAddressingIdentifier, OCABundleSerializationError> - Result with computed SAID or an error if serialization or digest computation fails.